public static class ListNamespacesRequest.Builder extends Object implements BmcRequest.Builder<ListNamespacesRequest,Void>
| Constructor and Description |
|---|
Builder() |
| Modifier and Type | Method and Description |
|---|---|
ListNamespacesRequest |
build()
Build the instance of ListNamespacesRequest as configured by this builder
|
ListNamespacesRequest |
buildWithoutInvocationCallback()
Build the instance of ListNamespacesRequest as configured by this builder
|
ListNamespacesRequest.Builder |
compartmentId(String compartmentId)
The ID of the compartment in which to list resources.
|
ListNamespacesRequest.Builder |
copy(ListNamespacesRequest o)
Copy method to populate the builder with values from the given instance.
|
ListNamespacesRequest.Builder |
invocationCallback(com.oracle.bmc.http.client.RequestInterceptor invocationCallback)
Set the invocation callback for the request to be built.
|
ListNamespacesRequest.Builder |
opcRequestId(String opcRequestId)
The client request ID for tracing.
|
ListNamespacesRequest.Builder |
retryConfiguration(RetryConfiguration retryConfiguration)
Set the retry configuration for the request to be built.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitbody$public ListNamespacesRequest.Builder compartmentId(String compartmentId)
The ID of the compartment in which to list resources.
compartmentId - the value to setpublic ListNamespacesRequest.Builder opcRequestId(String opcRequestId)
The client request ID for tracing.
opcRequestId - the value to setpublic ListNamespacesRequest.Builder invocationCallback(com.oracle.bmc.http.client.RequestInterceptor invocationCallback)
Set the invocation callback for the request to be built.
invocationCallback - the invocation callback to be set for the requestpublic ListNamespacesRequest.Builder retryConfiguration(RetryConfiguration retryConfiguration)
Set the retry configuration for the request to be built.
retryConfiguration - the retry configuration to be used for the requestpublic ListNamespacesRequest.Builder copy(ListNamespacesRequest o)
Copy method to populate the builder with values from the given instance.
copy in interface BmcRequest.Builder<ListNamespacesRequest,Void>o - other request from which to copy valuespublic ListNamespacesRequest build()
Build the instance of ListNamespacesRequest as configured by this builder
Note that this method takes calls to invocationCallback(com.oracle.bmc.http.client.RequestInterceptor) into account,
while the method buildWithoutInvocationCallback() does not.
This is the preferred method to build an instance.
build in interface BmcRequest.Builder<ListNamespacesRequest,Void>public ListNamespacesRequest buildWithoutInvocationCallback()
Build the instance of ListNamespacesRequest as configured by this builder
Note that this method does not take calls to invocationCallback(com.oracle.bmc.http.client.RequestInterceptor) into account,
while the method build() does
Copyright © 2016–2024. All rights reserved.